typed_descriptors.attr
======================

.. automodule:: typed_descriptors.attr

Attr
----

.. autoclass:: typed_descriptors.attr.Attr
    :show-inheritance:
    :members:
    :special-members: __init__, __set_name__, __set__, __get__

SupportsBool
------------

.. autoclass:: typed_descriptors.attr.SupportsBool
    :show-inheritance:
    :members:

T_contra
--------

.. autodata:: typed_descriptors.attr.T_contra

ValidatedAttrFactory
--------------------

.. autoclass:: typed_descriptors.attr.ValidatedAttrFactory
    :show-inheritance:
    :members:

ValidatorFunction
-----------------

.. autoclass:: typed_descriptors.attr.ValidatorFunction
    :show-inheritance:
    :members:

validate_validator_fun
----------------------

.. autofunction:: typed_descriptors.attr.validate_validator_fun

validator_fun_value_type
------------------------

.. autofunction:: typed_descriptors.attr.validator_fun_value_type
